==> kardsgt-0.4.0.tar.gz: kardsgt-0.4.0/kardsgt-0.4.0-src/src/players/wally/wally.h <==
/***************************************************************************
 *   Copyright (C) 2006 by John Schneiderman                               *
 *   JohnMS@member.fsf.org                                                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.             *
 ***************************************************************************/
#ifndef WALLY_H
#define WALLY_H

#include "aibase.h"
#include "player.h"

class Card;
class CardSequence;
class RuleBase;

/**
 * This is the character strategies for Wally.
 *
 * @author John Schneiderman
 */
class Wally: public AIBase
{
public:
    /**
     * The default constructor.
     */
    Wally();
    /**
     * The default destructor.
     */
    virtual ~Wally();
    /**
     * The name of our player.
     * @return Wally.
     */
    virtual QString name() const;
    /**
     * Selects the cards we want to play.
     * @param game the name of the game or game phase we're currently playing.
     * @param playSequence is the current play sequence.
     * @param rules is the rules to the game.
     * @param hand is our current hand.
     * @param specialInformation is the game state information provided from the game.
     * @return the cards we want to play.
     */
    virtual CardSequence whichCards(const QString &game, const CardSequence &playSequence, const RuleBase &rules, const CardSequence &hand, const GameInformation &specialInformation) const;
    /**
     * The makes a bid based on his hand.
     * @param game is the game or game phase he's playing.
     * @param playSequence is the current play sequence.
     * @param rules are the rules for the game.
     * @param hand is his current hand.
     * @param specialInformation is the game state information provided from the game.
     * @param score is our current score in the game.
     * @return our bid.
     */
    virtual int bidAt(const QString &game, const CardSequence &playSequence, const RuleBase &rules, const CardSequence &hand, const GameInformation &specialInformation, int score) const;
    /**
     * An accessor to our player's skill level.
     * @param game is the game we want to know the skill level for.
     * @return the skill level based on game. If the game is not found the skill level of Newb is returned.
     */
    virtual Player::skill_Level skillLevel(const QString &game) const;

private:
    // Card Handling methods
    /**
     * Handles the cribbage ai.
     * @param game is the phase of the game we're in.
     * @param playSequence is the current play sequence.
     * @param rules is the rules for our game.
     * @param hand is our hand.
     * @return the cards we've selected.
     * @throw KardsGTError if we cannot determine what to do with game.
     */
    CardSequence handleCribbageCards(const QString& game, const CardSequence &playSequence, const RuleBase &rules, const CardSequence &hand) const;
    /**
     * Handles the hearts ai.
     * @param game is the phase of the game we're in.
     * @param playSequence is the current play sequence.
     * @param rules is the rules for our game.
     * @param hand is our hand.
     * @return the cards we've selected.
     * @throw KardsGTError if we cannot determine what to do with game.
     */
    CardSequence handleHeartsCards(const QString& game, const CardSequence &playSequence, const RuleBase &rules, const CardSequence &hand) const;
    /**
     * Handles the spades ai.
     * @param game is the phase of the game we're in.
     * @param playSequence is the current play sequence.
     * @param rules is the rules for our game.
     * @param hand is our hand.
     * @param specialInformation is the game state information provided from the game.
     * @return the cards we've selected.
     * @throw KardsGTError if we cannot determine what to do with game.
     */
    CardSequence handleSpadesCards(const QString& game, const CardSequence &playSequence, const RuleBase &rules, const CardSequence &hand, const GameInformation &specialInformation) const;
    // Bid Handling methods
    /**
     * Handles the bidding ai for spades.
     * @param game is the phase of the game we're
     * @param playSequence is the current play sequence.
     * @param rules is the rules for our game.
     * @param hand is our hand.
     * @param specialInformation is the game state information provided from the game.
     * @param score is our current score in the game.
     * @return our bid.
     */
    int handleSpadesBid(const QString &game, const CardSequence &playSequence, const RuleBase &rules, const CardSequence &hand, const GameInformation &specialInformation, int score) const;
};
#endif

==> kardsgt-0.6.0.tar.gz: kardsgt-0.6.0/kardsgt-0.6.0-src/src/players/wally/wally.h <==
/***************************************************************************
 *   Copyright (C) 2006 by John Schneiderman                               *
 *   JohnMS@member.fsf.org                                                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.             *
 ***************************************************************************/
#ifndef WALLY_H
#define WALLY_H

#include "aibase.h"
#include "player.h"

class Card;
class CardSequence;
class RuleBase;

/**
 * This is the character strategies for Wally.
 *
 * @author John Schneiderman
 */
class Wally: public AIBase
{
public:
    /**
     * The default constructor.
     */
    Wally();
    /**
     * The default destructor.
     */
    virtual ~Wally();
    /**
     * The name of our player.
     * @return Wally.
     */
    virtual QString name() const;
    /**
     * Selects the cards we want to play.
     * @param game the name of the game or game phase we're currently playing.
     * @param playSequence is the current play sequence.
     * @param rules is the rules to the game.
     * @param hand is our current hand.
     * @param specialInformation is the game state information provided from the game.
     * @return the cards we want to play.
     */
    virtual CardSequence whichCards(const QString &game, const CardSequence &playSequence, const RuleBase &rules, const CardSequence &hand, const GameInformation &specialInformation) const;
    /**
     * The makes a decision based on his hand.
     * @param game is the game or game phase he's playing.
     * @param playSequence is the current play sequence.
     * @param rules are the rules for the game.
     * @param hand is his current hand.
     * @param specialInformation is the game state information provided from the game.
     * @param score is our current score in the game.
     * @return the decision he disires, or if game cannot be determined a random number [1, 100].
     */
    virtual int decision(const QString &game, const CardSequence &playSequence, const RuleBase &rules, const CardSequence &hand, const GameInformation &specialInformation, int score) const;
    /**
     * An accessor to our player's skill level.
     * @param game is the game we want to know the skill level for.
     * @return the skill level based on game. If the game is not found the skill level of Newb is returned.
     */
    virtual Player::skill_Level skillLevel(const QString &game) const;

private:
    // Card Handling methods
    /**
     * Handles the cribbage ai.
     * @param game is the phase of the game we're in.
     * @param playSequence is the current play sequence.
     * @param rules is the rules for our game.
     * @param hand is our hand.
     * @return the cards we've selected.
     * @throw KardsGTError if we cannot determine what to do with game.
     */
    CardSequence handleCribbageCards(const QString& game, const CardSequence &playSequence, const RuleBase &rules, const CardSequence &hand) const;
    /**
     * Handles the hearts ai.
     * @param game is the phase of the game we're in.
     * @param playSequence is the current play sequence.
     * @param rules is the rules for our game.
     * @param hand is our hand.
     * @return the cards we've selected.
     * @throw KardsGTError if we cannot determine what to do with game.
     */
    CardSequence handleHeartsCards(const QString& game, const CardSequence &playSequence, const RuleBase &rules, const CardSequence &hand) const;
    /**
     * Handles the spades ai.
     * @param game is the phase of the game we're in.
     * @param playSequence is the current play sequence.
     * @param rules is the rules for our game.
     * @param hand is our hand.
     * @param specialInformation is the game state information provided from the game.
     * @return the cards we've selected.
     * @throw KardsGTError if we cannot determine what to do with game.
     */
    CardSequence handleSpadesCards(const QString& game, const CardSequence &playSequence, const RuleBase &rules, const CardSequence &hand, const GameInformation &specialInformation) const;
    /**
     * Handles the euchre ai.
     * @param game is the phase of the game we're in.
     * @param playSequence is the current play sequence.
     * @param rules is the rules for our game.
     * @param hand is our hand.
     * @param specialInformation is the game state information provided from the game.
     * @return the cards we've selected.
     * @throw KardsGTError if we cannot determine what to do with game.
     */
    CardSequence handleEuchreCards(const QString& game, const CardSequence &playSequence, const RuleBase &rules, const CardSequence &hand, const GameInformation &specialInformation) const;
    // Bid Handling methods
    /**
     * Handles the bidding ai for spades.
     * @param game is the phase of the game we're
     * @param playSequence is the current play sequence.
     * @param rules is the rules for our game.
     * @param hand is our hand.
     * @param specialInformation is the game state information provided from the game.
     * @param score is our current score in the game.
     * @return our bid.
     */
    int handleSpadesBid(const QString &game, const CardSequence &playSequence, const RuleBase &rules, const CardSequence &hand, const GameInformation &specialInformation, int score) const;
    /**
     * Handles the bidding ai for euchre.
     * @param game is the phase of the game we're
     * @param playSequence is the current play sequence.
     * @param rules is the rules for our game.
     * @param hand is our hand.
     * @param specialInformation is the game state information provided from the game.
     * @param score is our current score in the game.
     * @return our decision.
     */
    int handleEuchreDecisions(const QString &game, const CardSequence &playSequence, const RuleBase &rules, const CardSequence &hand, const GameInformation &specialInformation, int score) const;
};
#endif
